From 40aa96676a682bedbc8ca46b7fb3e15e36cbaf26 Mon Sep 17 00:00:00 2001
From: Eric Davis <edavis@littlestreamsoftware.com>
Date: Thu, 16 Jun 2011 10:43:04 -0700
Subject: [PATCH] [#467] Fix uninitialized constant Journal::Journaled error

Was due to Journals touching the parent record but the Journal
not having it's STI class correct during the type update.
---
 db/migrate/20100714111651_generalize_journals.rb |   10 +++++++---
 1 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/db/migrate/20100714111651_generalize_journals.rb b/db/migrate/20100714111651_generalize_journals.rb
index 2dbea59..d4e20c8 100644
--- a/db/migrate/20100714111651_generalize_journals.rb
+++ b/db/migrate/20100714111651_generalize_journals.rb
@@ -35,10 +35,14 @@ class GeneralizeJournals < ActiveRecord::Migration
 
     Journal.all.group_by(&:journaled_id).each_pair do |id, journals|
       journals.sort_by(&:created_at).each_with_index do |j, idx|
-        j.update_attribute(:type, "#{j.journalized_type}Journal")
-        j.update_attribute(:version, idx + 1)
+        # Recast the basic Journal into it's STI journalized class so callbacks work (#467)
+        klass_name = "#{j.journalized_type}Journal"
+        j = j.becomes(klass_name.constantize)
+        j.type = klass_name
+        j.version = idx + 1
         # FIXME: Find some way to choose the right activity here
-        j.update_attribute(:activity_type, j.journalized_type.constantize.activity_provider_options.keys.first)
+        j.activity_type = j.journalized_type.constantize.activity_provider_options.keys.first
+        j.save(false)
       end
     end
 
-- 
1.7.4.1

